@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2010, 2012, 2013, 2014, 2015, 2018 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,24 +19,31 @@
 
 #include "window.h"
 
+#include "locale_dialog.h"
+
 #include <QApplication>
-#include <QLocale>
-#include <QTranslator>
 
 int main(int argc, char** argv) {
+#if !defined(Q_OS_MAC) && (QT_VERSION >= QT_VERSION_CHECK(5,6,0))
+	if (!qEnvironmentVariableIsSet("QT_DEVICE_PIXEL_RATIO")
+			&& !qEnvironmentVariableIsSet("QT_AUTO_SCREEN_SCALE_FACTOR")
+			&& !qEnvironmentVariableIsSet("QT_SCALE_FACTOR")
+			&& !qEnvironmentVariableIsSet("QT_SCREEN_SCALE_FACTORS")) {
+		QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+	}
+#endif
 	QApplication app(argc, argv);
 	app.setApplicationName("Hexalate");
-	app.setApplicationVersion("1.0.1");
+	app.setApplicationVersion(VERSIONSTR);
+	app.setApplicationDisplayName(Window::tr("Hexalate"));
 	app.setOrganizationDomain("gottcode.org");
 	app.setOrganizationName("GottCode");
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MAC)
+	app.setWindowIcon(QIcon::fromTheme("hexalate", QIcon(":/hexalate.png")));
+#endif
+	app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
-	QTranslator qt_translator;
-	qt_translator.load("qt_" + QLocale::system().name());
-	app.installTranslator(&qt_translator);
-
-	QTranslator translator;
-	translator.load("hexalate_" + QLocale::system().name());
-	app.installTranslator(&translator);
+	LocaleDialog::loadTranslator("hexalate_");
 
 	Window window;
 	window.show();
